On 10/10/2014 12:06 PM, Nikolai Kondrashov wrote:
On 10/09/2014 11:01 AM, Lukas Slebodnik wrote:
ehlo,
The simple patch is attached. The side effect of this patch is reduction time spent in the scan-make-tests from 9 minutes to 4 minutes.
Actually, there should be no reduction in overall run time, as tests will be analyzed when they're built in the following "make-check" stage.
This does reduce number of warnings in the report, though.
Nick